.. _requests_transport:

RequestsHTTPTransport
=====================

The RequestsHTTPTransport is a sync transport using the `requests`_ library
and allows you to send GraphQL queries using the HTTP protocol.

Reference: :class:`gql.transport.requests.RequestsHTTPTransport`

.. literalinclude:: ../code_examples/requests_sync.py

.. _requests: https://requests.readthedocs.io
